aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java
diff options
context:
space:
mode:
authorGravatar janakr <janakr@google.com>2018-02-26 09:06:33 -0800
committerGravatar Copybara-Service <copybara-piper@google.com>2018-02-26 09:09:37 -0800
commit0d38ab32d9fcd6ee6ad2d3ba511608f5989f31ef (patch)
treebf9d72995d228c083a38733e285daa0e930af31e /src/main/java
parent1c0bc2dece2a79d78a1caaea6b671b5341003a46 (diff)
@AutoCodec JavaHeaderCompileAction.
PiperOrigin-RevId: 187030267
Diffstat (limited to 'src/main/java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/java/JavaHeaderCompileAction.java14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/rules/java/JavaHeaderCompileAction.java b/src/main/java/com/google/devtools/build/lib/rules/java/JavaHeaderCompileAction.java
index b55d887433..719caf20be 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/java/JavaHeaderCompileAction.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/java/JavaHeaderCompileAction.java
@@ -50,6 +50,7 @@ import com.google.devtools.build.lib.cmdline.Label;
import com.google.devtools.build.lib.collect.nestedset.NestedSet;
import com.google.devtools.build.lib.collect.nestedset.NestedSetBuilder;
import com.google.devtools.build.lib.collect.nestedset.Order;
+import com.google.devtools.build.lib.skyframe.serialization.autocodec.AutoCodec;
import com.google.devtools.build.lib.util.Fingerprint;
import com.google.devtools.build.lib.util.LazyString;
import com.google.devtools.build.lib.vfs.PathFragment;
@@ -70,6 +71,7 @@ import javax.annotation.Nullable;
* <p>The implementation of the header compiler tool can be found under {@code
* //src/java_tools/buildjar/java/com/google/devtools/build/java/turbine}.
*/
+@AutoCodec
public class JavaHeaderCompileAction extends SpawnAction {
private static final String GUID = "952db158-2654-4ced-87e5-4646d50523cf";
@@ -93,28 +95,28 @@ public class JavaHeaderCompileAction extends SpawnAction {
* @param owner the action owner, typically a java_* RuleConfiguredTarget
* @param tools the set of files comprising the tool that creates the header interface jar
* @param directInputs the set of direct input artifacts of the compile action
- * @param transitiveInputs the set of transitive input artifacts of the compile action
+ * @param inputs the set of transitive input artifacts of the compile action
* @param outputs the outputs of the action
* @param directCommandLine the direct command line arguments for the java header compiler
* @param transitiveCommandLine the transitive command line arguments for the java header compiler
* @param progressMessage the message printed during the progression of the build
*/
protected JavaHeaderCompileAction(
ActionOwner owner,
Iterable<Artifact> tools,
Iterable<Artifact> directInputs,
- Iterable<Artifact> transitiveInputs,
+ Iterable<Artifact> inputs,
Iterable<Artifact> outputs,
CommandLine directCommandLine,
- CommandLine transitiveCommandLine,
+ CommandLine argv,
CharSequence progressMessage) {
super(
owner,
tools,
- transitiveInputs,
+ inputs,
outputs,
LOCAL_RESOURCES,
- transitiveCommandLine,
+ argv,
false,
// TODO(#3320): This is missing the config's action environment.
JavaCompileAction.UTF8_ACTION_ENVIRONMENT,
@@ -93,28 +95,28 @@ public class JavaHeaderCompileAction extends SpawnAction {
* @param outputs the outputs of the action
* @param directCommandLine the direct command line arguments for the java header compiler
- * @param transitiveCommandLine the transitive command line arguments for the java header compiler
+ * @param argv the transitive command line arguments for the java header compiler
* @param progressMessage the message printed during the progression of the build
*/